@@ -1,5 +1,9 @@
 package Test::HTML::Tidy::Recursive::Strict;
-$Test::HTML::Tidy::Recursive::Strict::VERSION = '0.6.0';
+$Test::HTML::Tidy::Recursive::Strict::VERSION = '0.6.1';
+use strict;
+use warnings;
+use autodie;
+
 use MooX qw/ late /;
 use HTML::T5 ();
 
@@ -25,7 +29,7 @@ using HTML::T5 while not ignoring warnings.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 SYNOPSIS
 
@@ -43,7 +47,7 @@ L<Test::HTML::Tidy::Recursive> documentation for more usage information.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 METHODS
 
